==> node-v12.4.0.tar.gz: node-v12.4.0/test/parallel/test-net-after-close.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';
const common = require('../common');
const assert = require('assert');
const net = require('net');

const server = net.createServer(common.mustCall(function(s) {
  console.error('SERVER: got connection');
  s.end();
}));

server.listen(0, common.mustCall(function() {
  const c = net.createConnection(this.address().port);
  c.on('close', common.mustCall(function() {
    console.error('connection closed');
    assert.strictEqual(c._handle, null);
    // Calling functions / accessing properties of a closed socket should not
    // throw.
    c.setNoDelay();
    c.setKeepAlive();
    c.bufferSize;
    c.pause();
    c.resume();
    c.address();
    c.remoteAddress;
    c.remotePort;
    server.close();
  }));
}));

==> node-v14.15.4.tar.gz: node-v14.15.4/test/parallel/test-net-after-close.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';
const common = require('../common');
const assert = require('assert');
const net = require('net');

const server = net.createServer(common.mustCall((s) => {
  console.error('SERVER: got connection');
  s.end();
}));

server.listen(0, common.mustCall(() => {
  const c = net.createConnection(server.address().port);
  c.on('close', common.mustCall(() => {
    console.error('connection closed');
    assert.strictEqual(c._handle, null);
    // Calling functions / accessing properties of a closed socket should not
    // throw.
    c.setNoDelay();
    c.setKeepAlive();
    c.bufferSize;
    c.pause();
    c.resume();
    c.address();
    c.remoteAddress;
    c.remotePort;
    server.close();
  }));
}));
